==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Select.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Dropdown } from "./Dropdown";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SelectDir_$type } from "./SelectDir";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Select = /*@__PURE__*/ (() => {
    class Select extends Dropdown {
        constructor() {
            super(...arguments);
            this.focus = null;
            this.blur = null;
        }
        get ak() {
            let ret_ = this.i.m("value");
            return ret_;
        }
        set ak(a) {
            let value_ = a;
            this.i.u("value", value_);
        }
        get ai() {
            let ret_ = this.i.m("name");
            return ret_;
        }
        set ai(a) {
            let value_ = a;
            this.i.u("name", value_);
        }
        get ad() {
            let ret_ = this.i.m("disabled");
            return ret_;
        }
        set ad(a) {
            let value_ = a;
            this.i.u("disabled", value_);
        }
        get ag() {
            let ret_ = this.i.m("required");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.i.u("required", value_);
        }
        get ae() {
            let ret_ = this.i.m("invalid");
            return ret_;
        }
        set ae(a) {
            let value_ = a;
            this.i.u("invalid", value_);
        }
        get af() {
            let ret_ = this.i.m("outlined");
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.i.u("outlined", value_);
        }
        get ac() {
            let ret_ = this.i.m("autofocus");
            return ret_;
        }
        set ac(a) {
            let value_ = a;
            this.i.u("autofocus", value_);
        }
        get ah() {
            let ret_ = this.i.m("label");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.i.u("label", value_);
        }
        get aj() {
            let ret_ = this.i.m("placeholder");
            return ret_;
        }
        set aj(a) {
            let value_ = a;
            this.i.u("placeholder", value_);
        }
        get z() {
            let ret_ = this.i.m("dir");
            ret_ = enumGetBox(SelectDir_$type, EnumUtil.getEnumValue(SelectDir_$type, this.i.f(SelectDir_$type, ret_)));
            return EnumUtil.getEnumValue(SelectDir_$type, ret_);
        }
        set z(a) {
            let value_ = enumGetBox(SelectDir_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("dir", value_);
        }
        focusChanged() {
            if (this.focus != null) {
                this.i.q("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.i.t("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.i.q("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.i.t("blur");
            }
        }
        ap(a) {
            this.nativeElement.focus(this.i.h(a));
        }
        am() {
            this.nativeElement.blur();
        }
        aq() {
            this.nativeElement.reportValidity();
        }
        an() {
            this.nativeElement.checkValidity();
        }
    }
    Select.$t = /*@__PURE__*/ markType(Select, 'Select', Dropdown.$);
    return Select;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Select.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Dropdown } from "./Dropdown";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SelectDir_$type } from "./SelectDir";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Select = /*@__PURE__*/ (() => {
    class Select extends Dropdown {
        constructor() {
            super(...arguments);
            this.focus = null;
            this.blur = null;
        }
        get ak() {
            let ret_ = this.i.n("value");
            return ret_;
        }
        set ak(a) {
            let value_ = a;
            this.i.v("value", value_);
        }
        get ai() {
            let ret_ = this.i.n("name");
            return ret_;
        }
        set ai(a) {
            let value_ = a;
            this.i.v("name", value_);
        }
        get ad() {
            let ret_ = this.i.n("disabled");
            return ret_;
        }
        set ad(a) {
            let value_ = a;
            this.i.v("disabled", value_);
        }
        get ag() {
            let ret_ = this.i.n("required");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.i.v("required", value_);
        }
        get ae() {
            let ret_ = this.i.n("invalid");
            return ret_;
        }
        set ae(a) {
            let value_ = a;
            this.i.v("invalid", value_);
        }
        get af() {
            let ret_ = this.i.n("outlined");
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.i.v("outlined", value_);
        }
        get ac() {
            let ret_ = this.i.n("autofocus");
            return ret_;
        }
        set ac(a) {
            let value_ = a;
            this.i.v("autofocus", value_);
        }
        get ah() {
            let ret_ = this.i.n("label");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.i.v("label", value_);
        }
        get aj() {
            let ret_ = this.i.n("placeholder");
            return ret_;
        }
        set aj(a) {
            let value_ = a;
            this.i.v("placeholder", value_);
        }
        get z() {
            let ret_ = this.i.n("dir");
            ret_ = enumGetBox(SelectDir_$type, EnumUtil.getEnumValue(SelectDir_$type, this.i.f(SelectDir_$type, ret_)));
            return EnumUtil.getEnumValue(SelectDir_$type, ret_);
        }
        set z(a) {
            let value_ = enumGetBox(SelectDir_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("dir", value_);
        }
        focusChanged() {
            if (this.focus != null) {
                this.i.r("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.i.u("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.i.r("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.i.u("blur");
            }
        }
        ap(a) {
            this.nativeElement.focus(this.i.i(a));
        }
        am() {
            this.nativeElement.blur();
        }
        aq() {
            this.nativeElement.reportValidity();
        }
        an() {
            this.nativeElement.checkValidity();
        }
    }
    Select.$t = /*@__PURE__*/ markType(Select, 'Select', Dropdown.$);
    return Select;
})();
